@@ -67,7 +67,7 @@ class FluxAgent:
         managed_files: list = [],
         working_dir: str = "/tmp",
         whitelisted_addresses: list = ["127.0.0.1"],
-        verify_source_address: bool = True,
+        verify_source_address: bool = False,
         signed_vault_connections: bool = False,
         zelid: str = "",
         subordinate: bool = False,
